@@ -2,7 +2,7 @@
 #define __PDLCORE_H
 
 /* version 20: memory-management changes */
-/* on 21, unify pdl_broadcast per_pdl_flags, par_flags; remove threadloop #defines; change creating to char; relocate struct pdl.value appropriately, remove pdl_null, safe_indterm */
+/* on 21, look for comments "CORE21", unify pdl_trans per_pdl_flags, par_flags; remove threadloop #defines; change creating to char; relocate struct pdl.value appropriately, remove pdl_null, safe_indterm, initbroadcaststruct to take trans & remove in[cd]_sizes, remove pdl_{read,writeback}data_affine */
 #define PDL_CORE_VERSION 20
 #define startbroadcastloop startthreadloop
 #define pdl_startbroadcastloop pdl_startthreadloop
@@ -153,7 +153,8 @@ void pdl_dump_anyval(PDL_Anyval v);
   X(barf_if_error, void, (pdl_error err)) \
   X(error_accumulate, pdl_error, (pdl_error err_current, pdl_error err_new)) \
   X(packpdls, pdl **, ( SV* sv, PDL_Indx *npdls )) \
-  X(unpackpdls, SV*, ( pdl **, PDL_Indx npdls ))
+  X(unpackpdls, SV*, ( pdl **, PDL_Indx npdls )) \
+  X(packstrings, char **, ( SV* sv, PDL_Indx *nstrings )) \
 
 /*************** Function prototypes *********************/
 #define X(sym, rettype, args) \
@@ -163,7 +164,7 @@ PDL_CORE_LIST(X)
 
 #define X(symbol, ctype, ppsym, ...) \
 PDL_Indx pdl_setav_ ## ppsym(ctype * pdata, AV* av, \
-	PDL_Indx* pdims, PDL_Long ndims, int level, ctype undefval, pdl *p);
+  PDL_Indx* pdims, PDL_Indx ndims, PDL_Indx level, ctype undefval, pdl *p);
 PDL_TYPELIST_ALL(X)
 #undef X
 
@@ -185,20 +186,16 @@ struct Core {
 
 typedef struct Core Core;
 
-#define PDL_DECLARE_PARAMETER(type, flag, name, pdlname, nullcheck) \
-  type *name ## _datap = ((type *)(PDL_REPRP_TRANS(pdlname, flag))); \
-  type *name ## _physdatap = ((type *)(pdlname->data)); \
+#define PDL_DECLARE_PARAMETER(type, name, pdlname, nullcheck, ppsym) \
+  type *name ## _datap = ((type *)(PDL_REPRP(pdlname))); \
   if ((nullcheck) && pdlname->nvals > 0 && !name ## _datap) \
-    return PDL_CORE_(make_error_simple)(PDL_EUSERERROR, "parameter " #name " got NULL data"); \
-  (void)name ## _physdatap;
+    return PDL_CORE_(make_error)(PDL_EUSERERROR, "parameter " #name "=%p got NULL data", pdlname); \
 
-#define PDL_DECLARE_PARAMETER_BADVAL(type, flag, name, pdlname, nullcheck) \
-  PDL_DECLARE_PARAMETER(type, flag, name, pdlname, nullcheck) \
-  type name ## _badval = 0; \
-  PDL_Anyval name ## _anyval_badval = PDL_CORE_(get_pdl_badvalue)(pdlname); \
-  (void)name ## _badval; \
-  (void)name ## _anyval_badval; \
-  ANYVAL_TO_CTYPE(name ## _badval, type, name ## _anyval_badval);
+#define PDL_DECLARE_PARAMETER_BADVAL(type, name, pdlname, nullcheck, ppsym) \
+  PDL_DECLARE_PARAMETER(type, name, pdlname, nullcheck, ppsym) \
+  PDL_Anyval name ## _anyval_badval = PDL_CORE_(get_pdl_badvalue)(pdlname); (void)name ## _anyval_badval; \
+  type name ## _badval = name ## _anyval_badval.value.ppsym; (void)name ## _badval; \
+  char name ## _badval_isnan = PDL_ISNAN_ ## ppsym(name ## _badval); (void) name ## _badval_isnan; \
 
 /* __PDLCORE_H */
 #endif
