@@ -200,8 +200,6 @@ is expected to have as geographical neighbours C<x+1,y>, C<x-1,y>,
 C<x,y+1>, C<x,y-1>, and the grid polygon-building relies on that.
 This is how, and why, the 3D earth in C<demo 3d> arranges its data.
 
- #!/usr/bin/perl
-
  use PDL;
  use PDL::Graphics::TriD;
 
@@ -355,7 +353,7 @@ contexts and options
 
 alias for mesh3d
 
-=item trigrid3d
+=head2 trigrid3d
 
 Show a triangular mesh, giving C<$vertices> and C<$faceidx> which is
 a series of triplets of indices into the vertices, each describing
@@ -367,7 +365,7 @@ C<ShowNormals> (off by default, useful for debugging).
 
 Implemented by C<PDL::Graphics::TriD::STrigrid_S>.
 
-=item trigrid3d_ns
+=head2 trigrid3d_ns
 
 Like L</trigrid3d>, but without shading or normals.
 
@@ -456,8 +454,8 @@ Implemented by C<PDL::Graphics::TriD::Image>.
 
 =for usage
 
- imagrdb3d ndarray(3,x,y), {OPTIONS}
- imagrdb3d [ndarray,...], {OPTIONS}
+ imagrgb3d ndarray(3,x,y), {OPTIONS}
+ imagrgb3d [ndarray,...], {OPTIONS}
 
 The ndarray gives the colors. The option allowed is Points,
 which should give 4 3D coordinates for the corners of the polygon,
@@ -484,6 +482,20 @@ Grab a 3D image from the screen.
 The returned ndarray has dimensions (3,$x,$y) and is of type float
 (currently). XXX This should be altered later.
 
+=head2 contour3d
+
+=for usage
+
+ contour3d $d,[$x,$y,$z],[$r,$g,$b], {OPTIONS}
+
+where C<$d> is a 2D pdl of data to be contoured. C<[$x,$y,$z]> define a 3D
+map of C<$d> into the visualization space. C<[$r,$g,$b]> is an optional C<[3,1]>
+ndarray specifying the contour color and C<$options> is a hash reference to
+a list of options documented below.  Contours can also be coloured by
+value using the set_color_table function.
+
+Implemented by L<PDL::Graphics::TriD::Contours>.
+
 =head2 hold3d, release3d
 
 =for ref
@@ -557,19 +569,6 @@ returns 0.
 
 Close the currently-open 3D window.
 
-=head1 NOT EXPORTED
-
-These functions are not exported, partly because they are not fully
-implemented.
-
-=over
-
-=item contour3d
-
-Implemented by C<PDL::Graphics::TriD::Contours>.
-
-=back
-
 =head1 CONCEPTS
 
 The key concepts (object types) of TriD are explained in the following:
@@ -665,8 +664,6 @@ to the previous viewport in the (0,1) range.
 Every implementation-level window object should implement the new_viewport
 method.
 
-=head1 EXAMPLE SCRIPT FOR VARIOUS
-
 =cut
 
 #KGB: NEEDS DOCS ON COMMON OPTIONS!!!!!
@@ -692,7 +689,7 @@ use PDL::Core '';  # barf
 our @ISA = qw/PDL::Exporter/;
 our @EXPORT_OK = qw/imag3d_ns imag3d line3d mesh3d lattice3d points3d
   trigrid3d trigrid3d_ns
-  spheres3d describe3d imagrgb imagrgb3d hold3d release3d
+  contour3d spheres3d describe3d imagrgb imagrgb3d hold3d release3d
   keeptwiddling3d nokeeptwiddling3d close3d
   twiddle3d grabpic3d tridsettings/;
 our %EXPORT_TAGS = (Func=>\@EXPORT_OK);
@@ -869,7 +866,7 @@ sub PDL::line3d {
 
 *contour3d=*contour3d=\&PDL::contour3d;
 sub PDL::contour3d {
-#  &checkargs;
+  &checkargs;
   require PDL::Graphics::TriD::Contours;
   graph_object(PDL::Graphics::TriD::Contours->new(@_));
 }
